==> zola-0.19.0.tar.gz: zola-0.19.0/docs/content/themes/duckquill/index.md <==

+++
title = "Duckquill"
description = "Modern, pretty, and clean theme"
template = "theme.html"
date = 2024-06-13T08:07:01-05:00

[extra]
created = 2024-06-13T08:07:01-05:00
updated = 2024-06-13T08:07:01-05:00
repository = "https://codeberg.org/daudix/duckquill.git"
homepage = "https://codeberg.org/daudix/duckquill"
minimum_version = "0.17.2"
license = "MIT"
demo = "https://daudix.codeberg.page/duckquill"

[extra.author]
name = "David Lapshin"
homepage = "https://daudix.codeberg.page"
+++        

[![Please don't upload to GitHub](https://nogithub.codeberg.page/badge.svg)](https://nogithub.codeberg.page)
[![MIT license](https://img.shields.io/badge/License-MIT-blue)](https://mit-license.org)
[![status-badge](https://ci.codeberg.org/api/badges/13032/status.svg)](https://ci.codeberg.org/repos/13032)

# [Duckquill](https://daudix.codeberg.page/duckquill/) <img src="logo.png" alt="Logo" width="96" align="right"/>

Duckquill is a modern, pretty, and clean (and opinionated) [Zola](https://www.getzola.org) theme that has the purpose of greatly simplifying the process of rolling up your blog. It aims to provide all the needed options for comfortable writing, keeping the balance of it being simple.

![Screenshot](screenshot.png)

## Docs

Docs are provided in form of a [live demo](https://daudix.codeberg.page/duckquill).

## Know your rights

This website is under the MIT license:

- **Freedom to Use**: You have the right to use the software for any purpose, whether it's personal, academic, or commercial.
- **Freedom to Modify**: You can modify the source code of the software to suit your needs or preferences.
- **Freedom to Distribute**: You have the right to distribute the software, whether in its original form or modified, to others.
- **Collaboration**: You can collaborate with others on the software's development and improvement.
- **No License Compatibility Issues**: You can combine the MIT-licensed software with other software, even if they use different licenses.
- **No Usage Restrictions**: There are no restrictions on the technologies or fields of use, giving you maximum flexibility.
- **No Royalties**: You are not required to pay any royalties or fees for using, modifying, or distributing the software.

## Contributing guidelines

There are several ways to contribute to this project:

- Reporting issues
- Discussing potential improvements
- Contributing code
- Writing documentation
- Submitting feature requests
- Providing feedback

When making any sort of contribution, please make sure to follow [Forgejo's Code of Conduct](https://codeberg.org/forgejo/code-of-conduct). If you don't have the time to read it, just know that all you have to do is be nice, and you'll be just fine.

*</> with <3 by [daudix](https://daudix.codeberg.page) | README based on [libreivan's](https://codeberg.org/libreivan/libreivan.com)*

==> zola-0.21.0.tar.gz: zola-0.21.0/docs/content/themes/duckquill/index.md <==

+++
title = "Duckquill"
description = "Modern, pretty, and clean theme"
template = "theme.html"
date = 2025-06-01T01:24:00+02:00

[taxonomies]
theme-tags = []

[extra]
created = 2025-06-01T01:24:00+02:00
updated = 2025-06-01T01:24:00+02:00
repository = "https://codeberg.org/daudix/duckquill.git"
homepage = "https://codeberg.org/daudix/duckquill"
minimum_version = "0.19.0"
license = "MIT"
demo = "https://duckquill.daudix.one"

[extra.author]
name = "David Lapshin"
homepage = "https://daudix.one"
+++        

[![Please don't upload to GitHub](https://nogithub.codeberg.page/badge.svg)](https://nogithub.codeberg.page)
[![MIT license](https://img.shields.io/badge/License-MIT-blue)](https://mit-license.org)
[![status-badge](https://ci.codeberg.org/api/badges/13032/status.svg)](https://ci.codeberg.org/repos/13032)

# [Duckquill](https://duckquill.daudix.one)

Duckquill is an opinionated, modern, pretty, and clean [Zola](https://www.getzola.org) theme that has the purpose of greatly simplifying the process of rolling up your blog. It aims to provide all the necessary options for comfortable writing, while keeping the balance of simplicity.

![Screenshot](screenshot.png)

## Docs

Docs are provided in form of a [live demo](https://duckquill.daudix.one).

## Know your rights

This project is under the MIT license:

- **Freedom to Use**: You have the right to use the software for any purpose, whether it's personal, academic, or commercial.
- **Freedom to Modify**: You can modify the source code of the software to suit your needs or preferences.
- **Freedom to Distribute**: You have the right to distribute the software, whether in its original form or modified, to others.
- **Collaboration**: You can collaborate with others on the software's development and improvement.
- **No License Compatibility Issues**: You can combine the MIT-licensed software with other software, even if they use different licenses.
- **No Usage Restrictions**: There are no restrictions on the technologies or fields of use, giving you maximum flexibility.
- **No Royalties**: You are not required to pay any royalties or fees for using, modifying, or distributing the software.

## Contributing guidelines

There are several ways to contribute to this project:

- Reporting issues
- Discussing potential improvements
- Contributing code
- Writing documentation
- Submitting feature requests
- Providing feedback

When making any sort of contribution, please make sure to follow [Forgejo's Code of Conduct](https://codeberg.org/forgejo/code-of-conduct). If you don't have the time to read it, just know that all you have to do is be nice, and you'll be just fine.

*</> with <3 by [daudix](https://daudix.one) | README based on [libreivan's](https://codeberg.org/libreivan/libreivan.com)*
